Module: Google::Apis::BeyondcorpV1alpha
- Defined in:
- lib/google/apis/beyondcorp_v1alpha.rb,
lib/google/apis/beyondcorp_v1alpha/classes.rb,
lib/google/apis/beyondcorp_v1alpha/service.rb,
lib/google/apis/beyondcorp_v1alpha/gem_version.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb
Overview
BeyondCorp API
Chrome Enterprise Premium is a secure enterprise browsing solution that provides secure access to applications and resources, and offers integrated threat and data protection. It adds an extra layer of security to safeguard your Chrome browser environment, including Data Loss Prevention (DLP), real- time URL and file scanning, and Context-Aware Access for SaaS and web apps.
Defined Under Namespace
Classes: AllocatedConnection, AppGateway, AppGatewayOperationMetadata, ApplicationEndpoint, BeyondCorpService, CloudPubSubNotificationConfig, CloudSecurityZerotrustApplinkAppConnectorProtoConnectionConfig, CloudSecurityZerotrustApplinkAppConnectorProtoConnectorDetails, CloudSecurityZerotrustApplinkAppConnectorProtoGateway, CloudSecurityZerotrustApplinkLogagentProtoLogAgentDetails, Connection, ConnectionDetails, ConnectionOperationMetadata, Connector, ConnectorInstanceConfig, ConnectorOperationMetadata, ContainerHealthDetails, Empty, Gateway, GoogleCloudBeyondcorpAppconnectionsV1AppConnectionOperationMetadata, GoogleCloudBeyondcorpAppconnectionsV1alphaAppConnection, GoogleCloudBeyondcorpAppconnectionsV1alphaAppConnectionApplicationEndpoint, GoogleCloudBeyondcorpAppconnectionsV1alphaAppConnectionGateway, GoogleCloudBeyondcorpAppconnectionsV1alphaAppConnectionOperationMetadata, GoogleCloudBeyondcorpAppconnectionsV1alphaListAppConnectionsResponse, GoogleCloudBeyondcorpAppconnectionsV1alphaResolveAppConnectionsResponse, GoogleCloudBeyondcorpAppconnectionsV1alphaResolveAppConnectionsResponseAppConnectionDetails, GoogleCloudBeyondcorpAppconnectorsV1AppConnectorOperationMetadata, GoogleCloudBeyondcorpAppconnectorsV1ContainerHealthDetails, GoogleCloudBeyondcorpAppconnectorsV1RemoteAgentDetails, GoogleCloudBeyondcorpAppconnectorsV1alphaAppConnector, GoogleCloudBeyondcorpAppconnectorsV1alphaAppConnectorInstanceConfig, GoogleCloudBeyondcorpAppconnectorsV1alphaAppConnectorOperationMetadata, GoogleCloudBeyondcorpAppconnectorsV1alphaAppConnectorPrincipalInfo, GoogleCloudBeyondcorpAppconnectorsV1alphaAppConnectorPrincipalInfoServiceAccount, GoogleCloudBeyondcorpAppconnectorsV1alphaContainerHealthDetails, GoogleCloudBeyondcorpAppconnectorsV1alphaImageConfig, GoogleCloudBeyondcorpAppconnectorsV1alphaListAppConnectorsResponse, GoogleCloudBeyondcorpAppconnectorsV1alphaNotificationConfig, GoogleCloudBeyondcorpAppconnectorsV1alphaNotificationConfigCloudPubSubNotificationConfig, GoogleCloudBeyondcorpAppconnectorsV1alphaRemoteAgentDetails, GoogleCloudBeyondcorpAppconnectorsV1alphaReportStatusRequest, GoogleCloudBeyondcorpAppconnectorsV1alphaResolveInstanceConfigResponse, GoogleCloudBeyondcorpAppconnectorsV1alphaResourceInfo, GoogleCloudBeyondcorpAppgatewaysV1AppGatewayOperationMetadata, GoogleCloudBeyondcorpPartnerservicesV1alphaPartnerServiceOperationMetadata, GoogleCloudBeyondcorpPartnerservicesV1mainPartnerServiceOperationMetadata, GoogleCloudBeyondcorpSaasplatformInsightsV1alphaAppliedConfig, GoogleCloudBeyondcorpSaasplatformInsightsV1alphaConfiguredInsightResponse, GoogleCloudBeyondcorpSaasplatformInsightsV1alphaCustomGrouping, GoogleCloudBeyondcorpSaasplatformInsightsV1alphaInsight, GoogleCloudBeyondcorpSaasplatformInsightsV1alphaInsightMetadata, GoogleCloudBeyondcorpSaasplatformInsightsV1alphaInsightMetadataField, GoogleCloudBeyondcorpSaasplatformInsightsV1alphaListInsightsResponse, GoogleCloudBeyondcorpSaasplatformInsightsV1alphaRow, GoogleCloudBeyondcorpSaasplatformInsightsV1alphaRowFieldVal, GoogleCloudBeyondcorpSaasplatformSubscriptionsV1alphaCancelSubscriptionResponse, GoogleCloudBeyondcorpSaasplatformSubscriptionsV1alphaListSubscriptionsResponse, GoogleCloudBeyondcorpSaasplatformSubscriptionsV1alphaRestartSubscriptionResponse, GoogleCloudBeyondcorpSaasplatformSubscriptionsV1alphaSubscription, GoogleCloudBeyondcorpSecuritygatewaysV1SecurityGatewayOperationMetadata, GoogleCloudBeyondcorpSecuritygatewaysV1alphaApplication, GoogleCloudBeyondcorpSecuritygatewaysV1alphaApplicationUpstream, GoogleCloudBeyondcorpSecuritygatewaysV1alphaApplicationUpstreamExternal, GoogleCloudBeyondcorpSecuritygatewaysV1alphaApplicationUpstreamNetwork, GoogleCloudBeyondcorpSecuritygatewaysV1alphaContextualHeaders, GoogleCloudBeyondcorpSecuritygatewaysV1alphaContextualHeadersDelegatedDeviceInfo, GoogleCloudBeyondcorpSecuritygatewaysV1alphaContextualHeadersDelegatedGroupInfo, GoogleCloudBeyondcorpSecuritygatewaysV1alphaContextualHeadersDelegatedUserInfo, GoogleCloudBeyondcorpSecuritygatewaysV1alphaEgressPolicy, GoogleCloudBeyondcorpSecuritygatewaysV1alphaEndpoint, GoogleCloudBeyondcorpSecuritygatewaysV1alphaEndpointMatcher, GoogleCloudBeyondcorpSecuritygatewaysV1alphaHub, GoogleCloudBeyondcorpSecuritygatewaysV1alphaInternetGateway, GoogleCloudBeyondcorpSecuritygatewaysV1alphaListApplicationsResponse, GoogleCloudBeyondcorpSecuritygatewaysV1alphaListSecurityGatewaysResponse, GoogleCloudBeyondcorpSecuritygatewaysV1alphaLoggingConfig, GoogleCloudBeyondcorpSecuritygatewaysV1alphaProxyProtocolConfig, GoogleCloudBeyondcorpSecuritygatewaysV1alphaSecurityGateway, GoogleCloudBeyondcorpSecuritygatewaysV1alphaSecurityGatewayOperationMetadata, GoogleCloudBeyondcorpSecuritygatewaysV1alphaServiceDiscovery, GoogleCloudBeyondcorpSecuritygatewaysV1alphaServiceDiscoveryApiGateway, GoogleCloudBeyondcorpSecuritygatewaysV1alphaServiceDiscoveryApiGatewayOperationDescriptor, GoogleCloudLocationListLocationsResponse, GoogleCloudLocationLocation, GoogleIamV1AuditConfig, GoogleIamV1AuditLogConfig, GoogleIamV1Binding, GoogleIamV1Policy, GoogleIamV1SetIamPolicyRequest, GoogleIamV1TestIamPermissionsRequest, GoogleIamV1TestIamPermissionsResponse, GoogleLongrunningCancelOperationRequest, GoogleLongrunningListOperationsResponse, GoogleLongrunningOperation, GoogleRpcStatus, GoogleTypeExpr, ImageConfig, ListAppGatewaysResponse, ListConnectionsResponse, ListConnectorsResponse, NotificationConfig, PrincipalInfo, RemoteAgentDetails, ReportStatusRequest, ResolveConnectionsResponse, ResolveInstanceConfigResponse, ResourceInfo, ServiceAccount, Tunnelv1ProtoTunnelerError, Tunnelv1ProtoTunnelerInfo
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-beyondcorp_v1alpha gem
"0.62.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.18.0"- REVISION =
Revision of the discovery document this client was generated from
"20260401"- VERSION =
Version of the BeyondCorp API this client connects to. This is NOT the gem version.
'V1alpha'- AUTH_CLOUD_PLATFORM =
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.
'https://www.googleapis.com/auth/cloud-platform'