Class: Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpAppconnectorsV1alphaResourceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/beyondcorp_v1alpha/classes.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb

Overview

ResourceInfo represents the information or status of an app connector resource component that's used to report on various parts of the system. For example, ResourceInfo can be used to convey the status of a remote_agent, including the status of an appgateway for an runtime environment in a container instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudBeyondcorpAppconnectorsV1alphaResourceInfo

Returns a new instance of GoogleCloudBeyondcorpAppconnectorsV1alphaResourceInfo.



1781
1782
1783
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 1781

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Required. Unique Id for the resource. Corresponds to the JSON property id

Returns:

  • (String)


1757
1758
1759
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 1757

def id
  @id
end

#resourceHash<String,Object>

Specific details for the resource. This is for internal use only. Corresponds to the JSON property resource

Returns:

  • (Hash<String,Object>)


1762
1763
1764
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 1762

def resource
  @resource
end

#statusString

Overall health status. Overall status is derived based on the status of each sub level resources. Corresponds to the JSON property status

Returns:

  • (String)


1768
1769
1770
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 1768

def status
  @status
end

#subArray<Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpAppconnectorsV1alphaResourceInfo>

List of Info for the sub level resources. Corresponds to the JSON property sub



1773
1774
1775
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 1773

def sub
  @sub
end

#timeString

The timestamp to collect the info. It is suggested to be set by the topmost level resource only. Corresponds to the JSON property time

Returns:

  • (String)


1779
1780
1781
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 1779

def time
  @time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1786
1787
1788
1789
1790
1791
1792
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 1786

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @resource = args[:resource] if args.key?(:resource)
  @status = args[:status] if args.key?(:status)
  @sub = args[:sub] if args.key?(:sub)
  @time = args[:time] if args.key?(:time)
end