Class: Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSaasplatformInsightsV1alphaAppliedConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/beyondcorp_v1alpha/classes.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb

Overview

The configuration that was applied to generate the result.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudBeyondcorpSaasplatformInsightsV1alphaAppliedConfig

Returns a new instance of GoogleCloudBeyondcorpSaasplatformInsightsV1alphaAppliedConfig.



2007
2008
2009
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2007

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregationString

Output only. Aggregation type applied. Corresponds to the JSON property aggregation

Returns:

  • (String)


1979
1980
1981
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 1979

def aggregation
  @aggregation
end

#custom_groupingGoogle::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSaasplatformInsightsV1alphaCustomGrouping

Customised grouping option that allows setting the group_by fields and also the filters togather for a configured insight request. Corresponds to the JSON property customGrouping



1985
1986
1987
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 1985

def custom_grouping
  @custom_grouping
end

#end_timeString

Output only. Ending time for the duration for which insight was pulled. Corresponds to the JSON property endTime

Returns:

  • (String)


1990
1991
1992
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 1990

def end_time
  @end_time
end

#field_filterString

Output only. Filters applied. Corresponds to the JSON property fieldFilter

Returns:

  • (String)


1995
1996
1997
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 1995

def field_filter
  @field_filter
end

#groupString

Output only. Group id of the grouping applied. Corresponds to the JSON property group

Returns:

  • (String)


2000
2001
2002
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2000

def group
  @group
end

#start_timeString

Output only. Starting time for the duration for which insight was pulled. Corresponds to the JSON property startTime

Returns:

  • (String)


2005
2006
2007
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2005

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2012
2013
2014
2015
2016
2017
2018
2019
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2012

def update!(**args)
  @aggregation = args[:aggregation] if args.key?(:aggregation)
  @custom_grouping = args[:custom_grouping] if args.key?(:custom_grouping)
  @end_time = args[:end_time] if args.key?(:end_time)
  @field_filter = args[:field_filter] if args.key?(:field_filter)
  @group = args[:group] if args.key?(:group)
  @start_time = args[:start_time] if args.key?(:start_time)
end