Class: Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSaasplatformInsightsV1alphaInsight
- Inherits:
-
Object
- Object
- Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSaasplatformInsightsV1alphaInsight
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/beyondcorp_v1alpha/classes.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb
Overview
The Insight object with configuration that was returned and actual list of records.
Instance Attribute Summary collapse
-
#applied_config ⇒ Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSaasplatformInsightsV1alphaAppliedConfig
The configuration that was applied to generate the result.
-
#metadata ⇒ Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSaasplatformInsightsV1alphaInsightMetadata
Insight filters, groupings and aggregations that can be applied for the insight.
-
#name ⇒ String
Output only.
-
#rows ⇒ Array<Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSaasplatformInsightsV1alphaRow>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudBeyondcorpSaasplatformInsightsV1alphaInsight
constructor
A new instance of GoogleCloudBeyondcorpSaasplatformInsightsV1alphaInsight.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudBeyondcorpSaasplatformInsightsV1alphaInsight
Returns a new instance of GoogleCloudBeyondcorpSaasplatformInsightsV1alphaInsight.
2117 2118 2119 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2117 def initialize(**args) update!(**args) end |
Instance Attribute Details
#applied_config ⇒ Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSaasplatformInsightsV1alphaAppliedConfig
The configuration that was applied to generate the result.
Corresponds to the JSON property appliedConfig
2097 2098 2099 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2097 def applied_config @applied_config end |
#metadata ⇒ Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSaasplatformInsightsV1alphaInsightMetadata
Insight filters, groupings and aggregations that can be applied for the
insight. Examples: aggregations, groups, field filters.
Corresponds to the JSON property metadata
2103 2104 2105 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2103 def @metadata end |
#name ⇒ String
Output only. The insight resource name. e.g. organizations/organization_id/
locations/location_id/insights/insight_idOR `projects/`project_id`/
locations/`location_id`/insights/`insight_id.
Corresponds to the JSON property name
2110 2111 2112 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2110 def name @name end |
#rows ⇒ Array<Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSaasplatformInsightsV1alphaRow>
Output only. Result rows returned containing the required value(s).
Corresponds to the JSON property rows
2115 2116 2117 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2115 def rows @rows end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2122 2123 2124 2125 2126 2127 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2122 def update!(**args) @applied_config = args[:applied_config] if args.key?(:applied_config) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @rows = args[:rows] if args.key?(:rows) end |