Class: Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSecuritygatewaysV1SecurityGatewayOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/beyondcorp_v1alpha/classes.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudBeyondcorpSecuritygatewaysV1SecurityGatewayOperationMetadata

Returns a new instance of GoogleCloudBeyondcorpSecuritygatewaysV1SecurityGatewayOperationMetadata.



2531
2532
2533
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2531

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


2495
2496
2497
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2495

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2500
2501
2502
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2500

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


2505
2506
2507
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2505

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have been cancelled successfully have Operation. error value with a google.rpc.Status.code of 1, corresponding to Code. CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


2513
2514
2515
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2513

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


2519
2520
2521
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2519

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


2524
2525
2526
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2524

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


2529
2530
2531
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2529

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2536
2537
2538
2539
2540
2541
2542
2543
2544
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2536

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end