Class: Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSecuritygatewaysV1alphaProxyProtocolConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/beyondcorp_v1alpha/classes.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb

Overview

The configuration for the proxy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudBeyondcorpSecuritygatewaysV1alphaProxyProtocolConfig

Returns a new instance of GoogleCloudBeyondcorpSecuritygatewaysV1alphaProxyProtocolConfig.



2992
2993
2994
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_client_headersArray<String>

Optional. List of the allowed client header names. Corresponds to the JSON property allowedClientHeaders

Returns:

  • (Array<String>)


2966
2967
2968
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2966

def allowed_client_headers
  @allowed_client_headers
end

#client_ipBoolean Also known as: client_ip?

Optional. Client IP configuration. The client IP address is included if true. Corresponds to the JSON property clientIp

Returns:

  • (Boolean)


2971
2972
2973
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2971

def client_ip
  @client_ip
end

#contextual_headersGoogle::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSecuritygatewaysV1alphaContextualHeaders

Contextual headers configuration. Corresponds to the JSON property contextualHeaders



2977
2978
2979
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2977

def contextual_headers
  @contextual_headers
end

#gateway_identityString

Optional. The security gateway identity configuration. Corresponds to the JSON property gatewayIdentity

Returns:

  • (String)


2982
2983
2984
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2982

def gateway_identity
  @gateway_identity
end

#metadata_headersHash<String,String>

Optional. Custom resource specific headers along with the values. The names should conform to RFC 9110: >Field names can contain alphanumeric characters, hyphens, and periods, can contain only ASCII-printable characters and tabs, and must start with a letter. Corresponds to the JSON property metadataHeaders

Returns:

  • (Hash<String,String>)


2990
2991
2992
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2990

def 
  @metadata_headers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2997
2998
2999
3000
3001
3002
3003
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2997

def update!(**args)
  @allowed_client_headers = args[:allowed_client_headers] if args.key?(:allowed_client_headers)
  @client_ip = args[:client_ip] if args.key?(:client_ip)
  @contextual_headers = args[:contextual_headers] if args.key?(:contextual_headers)
  @gateway_identity = args[:gateway_identity] if args.key?(:gateway_identity)
  @metadata_headers = args[:metadata_headers] if args.key?(:metadata_headers)
end