Class: Google::Apis::BeyondcorpV1alpha::GoogleLongrunningListOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::BeyondcorpV1alpha::GoogleLongrunningListOperationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/beyondcorp_v1alpha/classes.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb
Overview
The response message for Operations.ListOperations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#operations ⇒ Array<Google::Apis::BeyondcorpV1alpha::GoogleLongrunningOperation>
A list of operations that matches the specified filter in the request.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse
constructor
A new instance of GoogleLongrunningListOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse
Returns a new instance of GoogleLongrunningListOperationsResponse.
3672 3673 3674 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3672 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
3657 3658 3659 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3657 def next_page_token @next_page_token end |
#operations ⇒ Array<Google::Apis::BeyondcorpV1alpha::GoogleLongrunningOperation>
A list of operations that matches the specified filter in the request.
Corresponds to the JSON property operations
3662 3663 3664 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3662 def operations @operations end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable resources. Populated when the request sets
ListOperationsRequest.return_partial_success and reads across collections.
For example, when attempting to list all resources across all supported
locations.
Corresponds to the JSON property unreachable
3670 3671 3672 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3670 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3677 3678 3679 3680 3681 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3677 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @operations = args[:operations] if args.key?(:operations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |