Class: Google::Apis::BeyondcorpV1alpha::GoogleRpcStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/beyondcorp_v1alpha/classes.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb

Overview

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleRpcStatus

Returns a new instance of GoogleRpcStatus.



3806
3807
3808
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3806

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeFixnum

The status code, which should be an enum value of google.rpc.Code. Corresponds to the JSON property code

Returns:

  • (Fixnum)


3791
3792
3793
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3791

def code
  @code
end

#detailsArray<Hash<String,Object>>

A list of messages that carry the error details. There is a common set of message types for APIs to use. Corresponds to the JSON property details

Returns:

  • (Array<Hash<String,Object>>)


3797
3798
3799
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3797

def details
  @details
end

#messageString

A developer-facing error message, which should be in English. Any user-facing error message should be localized and sent in the google.rpc.Status.details field, or localized by the client. Corresponds to the JSON property message

Returns:

  • (String)


3804
3805
3806
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3804

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3811
3812
3813
3814
3815
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3811

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @details = args[:details] if args.key?(:details)
  @message = args[:message] if args.key?(:message)
end