Class: Google::Apis::BeyondcorpV1alpha::ListConnectionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/beyondcorp_v1alpha/classes.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb

Overview

Response message for BeyondCorp.ListConnections.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListConnectionsResponse

Returns a new instance of ListConnectionsResponse.



3917
3918
3919
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3917

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connectionsArray<Google::Apis::BeyondcorpV1alpha::Connection>

A list of BeyondCorp Connections in the project. Corresponds to the JSON property connections



3904
3905
3906
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3904

def connections
  @connections
end

#next_page_tokenString

A token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3910
3911
3912
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3910

def next_page_token
  @next_page_token
end

#unreachableArray<String>

A list of locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3915
3916
3917
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3915

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3922
3923
3924
3925
3926
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3922

def update!(**args)
  @connections = args[:connections] if args.key?(:connections)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end