Class: Google::Apis::BeyondcorpV1alpha::ReportStatusRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/beyondcorp_v1alpha/classes.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb

Overview

Request report the connector status.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReportStatusRequest

Returns a new instance of ReportStatusRequest.



4042
4043
4044
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 4042

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_idString

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


4028
4029
4030
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 4028

def request_id
  @request_id
end

#resource_infoGoogle::Apis::BeyondcorpV1alpha::ResourceInfo

ResourceInfo represents the information/status of the associated resource. Corresponds to the JSON property resourceInfo



4033
4034
4035
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 4033

def resource_info
  @resource_info
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set, validates request by executing a dry-run which would not alter the resource in any way. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


4039
4040
4041
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 4039

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4047
4048
4049
4050
4051
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 4047

def update!(**args)
  @request_id = args[:request_id] if args.key?(:request_id)
  @resource_info = args[:resource_info] if args.key?(:resource_info)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end