Class: Google::Apis::BeyondcorpV1alpha::ResourceInfo
- Inherits:
-
Object
- Object
- Google::Apis::BeyondcorpV1alpha::ResourceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/beyondcorp_v1alpha/classes.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb
Overview
ResourceInfo represents the information/status of the associated resource.
Instance Attribute Summary collapse
-
#id ⇒ String
Required.
-
#resource ⇒ Hash<String,Object>
Specific details for the resource.
-
#status ⇒ String
Overall health status.
-
#sub ⇒ Array<Google::Apis::BeyondcorpV1alpha::ResourceInfo>
List of Info for the sub level resources.
-
#time ⇒ String
The timestamp to collect the info.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceInfo
constructor
A new instance of ResourceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceInfo
Returns a new instance of ResourceInfo.
4169 4170 4171 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 4169 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Required. Unique Id for the resource.
Corresponds to the JSON property id
4145 4146 4147 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 4145 def id @id end |
#resource ⇒ Hash<String,Object>
Specific details for the resource.
Corresponds to the JSON property resource
4150 4151 4152 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 4150 def resource @resource end |
#status ⇒ String
Overall health status. Overall status is derived based on the status of each
sub level resources.
Corresponds to the JSON property status
4156 4157 4158 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 4156 def status @status end |
#sub ⇒ Array<Google::Apis::BeyondcorpV1alpha::ResourceInfo>
List of Info for the sub level resources.
Corresponds to the JSON property sub
4161 4162 4163 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 4161 def sub @sub end |
#time ⇒ String
The timestamp to collect the info. It is suggested to be set by the topmost
level resource only.
Corresponds to the JSON property time
4167 4168 4169 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 4167 def time @time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4174 4175 4176 4177 4178 4179 4180 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 4174 def update!(**args) @id = args[:id] if args.key?(:id) @resource = args[:resource] if args.key?(:resource) @status = args[:status] if args.key?(:status) @sub = args[:sub] if args.key?(:sub) @time = args[:time] if args.key?(:time) end |