Class: Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSaasplatformInsightsV1alphaRowFieldVal
- Inherits:
-
Object
- Object
- Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSaasplatformInsightsV1alphaRowFieldVal
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/beyondcorp_v1alpha/classes.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb
Overview
Column or key value pair from the request as part of key to use in query or a single pair of the fetch response.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Output only.
-
#filter_alias ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#value ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudBeyondcorpSaasplatformInsightsV1alphaRowFieldVal
constructor
A new instance of GoogleCloudBeyondcorpSaasplatformInsightsV1alphaRowFieldVal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudBeyondcorpSaasplatformInsightsV1alphaRowFieldVal
Returns a new instance of GoogleCloudBeyondcorpSaasplatformInsightsV1alphaRowFieldVal.
2313 2314 2315 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2313 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Output only. Name of the field.
Corresponds to the JSON property displayName
2294 2295 2296 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2294 def display_name @display_name end |
#filter_alias ⇒ String
Output only. Field name to be used in filter while requesting configured
insight filtered on this field.
Corresponds to the JSON property filterAlias
2300 2301 2302 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2300 def filter_alias @filter_alias end |
#id ⇒ String
Output only. Field id.
Corresponds to the JSON property id
2305 2306 2307 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2305 def id @id end |
#value ⇒ String
Output only. Value of the field in string format. Acceptable values are
strings or numbers.
Corresponds to the JSON property value
2311 2312 2313 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2311 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2318 2319 2320 2321 2322 2323 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2318 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @filter_alias = args[:filter_alias] if args.key?(:filter_alias) @id = args[:id] if args.key?(:id) @value = args[:value] if args.key?(:value) end |