Class: Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSaasplatformSubscriptionsV1alphaSubscription
- Inherits:
-
Object
- Object
- Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSaasplatformSubscriptionsV1alphaSubscription
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/beyondcorp_v1alpha/classes.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb
Overview
A BeyondCorp Subscription resource represents BeyondCorp Enterprise Subscription. BeyondCorp Enterprise Subscription enables BeyondCorp Enterprise permium features for an organization.
Instance Attribute Summary collapse
-
#auto_renew_enabled ⇒ Boolean
(also: #auto_renew_enabled?)
Output only.
-
#billing_account ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#csg_customer ⇒ Boolean
(also: #csg_customer?)
Optional.
-
#end_time ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#seat_count ⇒ Fixnum
Optional.
-
#sku ⇒ String
Required.
-
#start_time ⇒ String
Optional.
-
#state ⇒ String
Output only.
-
#subscriber_type ⇒ String
Output only.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudBeyondcorpSaasplatformSubscriptionsV1alphaSubscription
constructor
A new instance of GoogleCloudBeyondcorpSaasplatformSubscriptionsV1alphaSubscription.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudBeyondcorpSaasplatformSubscriptionsV1alphaSubscription
Returns a new instance of GoogleCloudBeyondcorpSaasplatformSubscriptionsV1alphaSubscription.
2459 2460 2461 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2459 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_renew_enabled ⇒ Boolean Also known as: auto_renew_enabled?
Output only. Represents that, if subscription will renew or end when the term
ends.
Corresponds to the JSON property autoRenewEnabled
2394 2395 2396 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2394 def auto_renew_enabled @auto_renew_enabled end |
#billing_account ⇒ String
Optional. Name of the billing account in the format. e.g. billingAccounts/
123456-123456-123456 Required if Subscription is of Paid type.
Corresponds to the JSON property billingAccount
2401 2402 2403 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2401 def billing_account @billing_account end |
#create_time ⇒ String
Output only. Create time of the subscription.
Corresponds to the JSON property createTime
2406 2407 2408 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2406 def create_time @create_time end |
#csg_customer ⇒ Boolean Also known as: csg_customer?
Optional. Whether the subscription is being created as part of the Citrix flow.
If this field is set to true, the subscription should have both the
start_time and end_time set in the request and the billing account used will
be the Citrix master billing account regardless of what its set to in the
request. This field can only be set to true in create requests.
Corresponds to the JSON property csgCustomer
2415 2416 2417 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2415 def csg_customer @csg_customer end |
#end_time ⇒ String
Optional. End time of the subscription.
Corresponds to the JSON property endTime
2421 2422 2423 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2421 def end_time @end_time end |
#name ⇒ String
Identifier. Unique resource name of the Subscription. The name is ignored when
creating a subscription.
Corresponds to the JSON property name
2427 2428 2429 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2427 def name @name end |
#seat_count ⇒ Fixnum
Optional. Number of seats in the subscription.
Corresponds to the JSON property seatCount
2432 2433 2434 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2432 def seat_count @seat_count end |
#sku ⇒ String
Required. SKU of subscription.
Corresponds to the JSON property sku
2437 2438 2439 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2437 def sku @sku end |
#start_time ⇒ String
Optional. Start time of the subscription.
Corresponds to the JSON property startTime
2442 2443 2444 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2442 def start_time @start_time end |
#state ⇒ String
Output only. The current state of the subscription.
Corresponds to the JSON property state
2447 2448 2449 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2447 def state @state end |
#subscriber_type ⇒ String
Output only. Type of subscriber.
Corresponds to the JSON property subscriberType
2452 2453 2454 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2452 def subscriber_type @subscriber_type end |
#type ⇒ String
Required. Type of subscription.
Corresponds to the JSON property type
2457 2458 2459 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2457 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2464 def update!(**args) @auto_renew_enabled = args[:auto_renew_enabled] if args.key?(:auto_renew_enabled) @billing_account = args[:billing_account] if args.key?(:billing_account) @create_time = args[:create_time] if args.key?(:create_time) @csg_customer = args[:csg_customer] if args.key?(:csg_customer) @end_time = args[:end_time] if args.key?(:end_time) @name = args[:name] if args.key?(:name) @seat_count = args[:seat_count] if args.key?(:seat_count) @sku = args[:sku] if args.key?(:sku) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @subscriber_type = args[:subscriber_type] if args.key?(:subscriber_type) @type = args[:type] if args.key?(:type) end |