Class: Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSecuritygatewaysV1alphaApplication

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/beyondcorp_v1alpha/classes.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb

Overview

The information about an application resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudBeyondcorpSecuritygatewaysV1alphaApplication

Returns a new instance of GoogleCloudBeyondcorpSecuritygatewaysV1alphaApplication.



2587
2588
2589
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2587

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2546
2547
2548
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2546

def create_time
  @create_time
end

#display_nameString

Optional. An arbitrary user-provided name for the application resource. Cannot exceed 64 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


2552
2553
2554
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2552

def display_name
  @display_name
end

#endpoint_matchersArray<Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSecuritygatewaysV1alphaEndpointMatcher>

Optional. An array of conditions to match the application's network endpoint. Each element in the array is an EndpointMatcher object, which defines a specific combination of a hostname pattern and one or more ports. The application is considered matched if at least one of the EndpointMatcher conditions in this array is met (the conditions are combined using OR logic). Each EndpointMatcher must contain a hostname pattern, such as "example.com", and one or more port numbers specified as a string, such as "443". Hostname and port number examples: "*.example.com", "443" "example.com" and "22" " example.com" and "22,33" Corresponds to the JSON property endpointMatchers



2565
2566
2567
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2565

def endpoint_matchers
  @endpoint_matchers
end

#nameString

Identifier. Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


2570
2571
2572
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2570

def name
  @name
end

#schemaString

Optional. Type of the external application. Corresponds to the JSON property schema

Returns:

  • (String)


2575
2576
2577
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2575

def schema
  @schema
end

#update_timeString

Output only. Timestamp when the resource was last modified. Corresponds to the JSON property updateTime

Returns:

  • (String)


2580
2581
2582
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2580

def update_time
  @update_time
end

#upstreamsArray<Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSecuritygatewaysV1alphaApplicationUpstream>

Optional. Which upstream resources to forward traffic to. Corresponds to the JSON property upstreams



2585
2586
2587
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2585

def upstreams
  @upstreams
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2592
2593
2594
2595
2596
2597
2598
2599
2600
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 2592

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @endpoint_matchers = args[:endpoint_matchers] if args.key?(:endpoint_matchers)
  @name = args[:name] if args.key?(:name)
  @schema = args[:schema] if args.key?(:schema)
  @update_time = args[:update_time] if args.key?(:update_time)
  @upstreams = args[:upstreams] if args.key?(:upstreams)
end