Class: Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSecuritygatewaysV1alphaSecurityGateway
- Inherits:
-
Object
- Object
- Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSecuritygatewaysV1alphaSecurityGateway
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/beyondcorp_v1alpha/classes.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb
Overview
The information about a security gateway resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#delegating_service_account ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#external_ips ⇒ Array<String>
Output only.
-
#hubs ⇒ Hash<String,Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSecuritygatewaysV1alphaHub>
Optional.
-
#logging ⇒ Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSecuritygatewaysV1alphaLoggingConfig
Configuration for Cloud Logging.
-
#name ⇒ String
Identifier.
-
#proxy_protocol_config ⇒ Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSecuritygatewaysV1alphaProxyProtocolConfig
The configuration for the proxy.
-
#service_discovery ⇒ Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSecuritygatewaysV1alphaServiceDiscovery
Settings related to the Service Discovery.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudBeyondcorpSecuritygatewaysV1alphaSecurityGateway
constructor
A new instance of GoogleCloudBeyondcorpSecuritygatewaysV1alphaSecurityGateway.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudBeyondcorpSecuritygatewaysV1alphaSecurityGateway
Returns a new instance of GoogleCloudBeyondcorpSecuritygatewaysV1alphaSecurityGateway.
3102 3103 3104 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3102 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when the resource was created.
Corresponds to the JSON property createTime
3046 3047 3048 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3046 def create_time @create_time end |
#delegating_service_account ⇒ String
Output only. Service account used for operations that involve resources in
consumer projects.
Corresponds to the JSON property delegatingServiceAccount
3052 3053 3054 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3052 def delegating_service_account @delegating_service_account end |
#display_name ⇒ String
Optional. An arbitrary user-provided name for the SecurityGateway. Cannot
exceed 64 characters.
Corresponds to the JSON property displayName
3058 3059 3060 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3058 def display_name @display_name end |
#external_ips ⇒ Array<String>
Output only. IP addresses that will be used for establishing connection to the
endpoints.
Corresponds to the JSON property externalIps
3064 3065 3066 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3064 def external_ips @external_ips end |
#hubs ⇒ Hash<String,Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSecuritygatewaysV1alphaHub>
Optional. Map of Hubs that represents regional data path deployment with GCP
region as a key.
Corresponds to the JSON property hubs
3070 3071 3072 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3070 def hubs @hubs end |
#logging ⇒ Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSecuritygatewaysV1alphaLoggingConfig
Configuration for Cloud Logging.
Corresponds to the JSON property logging
3075 3076 3077 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3075 def logging @logging end |
#name ⇒ String
Identifier. Name of the resource.
Corresponds to the JSON property name
3080 3081 3082 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3080 def name @name end |
#proxy_protocol_config ⇒ Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSecuritygatewaysV1alphaProxyProtocolConfig
The configuration for the proxy.
Corresponds to the JSON property proxyProtocolConfig
3085 3086 3087 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3085 def proxy_protocol_config @proxy_protocol_config end |
#service_discovery ⇒ Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSecuritygatewaysV1alphaServiceDiscovery
Settings related to the Service Discovery.
Corresponds to the JSON property serviceDiscovery
3090 3091 3092 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3090 def service_discovery @service_discovery end |
#state ⇒ String
Output only. The operational state of the SecurityGateway.
Corresponds to the JSON property state
3095 3096 3097 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3095 def state @state end |
#update_time ⇒ String
Output only. Timestamp when the resource was last modified.
Corresponds to the JSON property updateTime
3100 3101 3102 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3100 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3107 3108 3109 3110 3111 3112 3113 3114 3115 3116 3117 3118 3119 |
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3107 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @delegating_service_account = args[:delegating_service_account] if args.key?(:delegating_service_account) @display_name = args[:display_name] if args.key?(:display_name) @external_ips = args[:external_ips] if args.key?(:external_ips) @hubs = args[:hubs] if args.key?(:hubs) @logging = args[:logging] if args.key?(:logging) @name = args[:name] if args.key?(:name) @proxy_protocol_config = args[:proxy_protocol_config] if args.key?(:proxy_protocol_config) @service_discovery = args[:service_discovery] if args.key?(:service_discovery) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |