Class: Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSecuritygatewaysV1alphaSecurityGateway

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/beyondcorp_v1alpha/classes.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb

Overview

The information about a security gateway resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudBeyondcorpSecuritygatewaysV1alphaSecurityGateway

Returns a new instance of GoogleCloudBeyondcorpSecuritygatewaysV1alphaSecurityGateway.



3069
3070
3071
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3069

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3013
3014
3015
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3013

def create_time
  @create_time
end

#delegating_service_accountString

Output only. Service account used for operations that involve resources in consumer projects. Corresponds to the JSON property delegatingServiceAccount

Returns:

  • (String)


3019
3020
3021
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3019

def 
  @delegating_service_account
end

#display_nameString

Optional. An arbitrary user-provided name for the SecurityGateway. Cannot exceed 64 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


3025
3026
3027
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3025

def display_name
  @display_name
end

#external_ipsArray<String>

Output only. IP addresses that will be used for establishing connection to the endpoints. Corresponds to the JSON property externalIps

Returns:

  • (Array<String>)


3031
3032
3033
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3031

def external_ips
  @external_ips
end

#hubsHash<String,Google::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSecuritygatewaysV1alphaHub>

Optional. Map of Hubs that represents regional data path deployment with GCP region as a key. Corresponds to the JSON property hubs



3037
3038
3039
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3037

def hubs
  @hubs
end

#loggingGoogle::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSecuritygatewaysV1alphaLoggingConfig

Configuration for Cloud Logging. Corresponds to the JSON property logging



3042
3043
3044
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3042

def logging
  @logging
end

#nameString

Identifier. Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


3047
3048
3049
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3047

def name
  @name
end

#proxy_protocol_configGoogle::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSecuritygatewaysV1alphaProxyProtocolConfig

The configuration for the proxy. Corresponds to the JSON property proxyProtocolConfig



3052
3053
3054
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3052

def proxy_protocol_config
  @proxy_protocol_config
end

#service_discoveryGoogle::Apis::BeyondcorpV1alpha::GoogleCloudBeyondcorpSecuritygatewaysV1alphaServiceDiscovery

Settings related to the Service Discovery. Corresponds to the JSON property serviceDiscovery



3057
3058
3059
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3057

def service_discovery
  @service_discovery
end

#stateString

Output only. The operational state of the SecurityGateway. Corresponds to the JSON property state

Returns:

  • (String)


3062
3063
3064
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3062

def state
  @state
end

#update_timeString

Output only. Timestamp when the resource was last modified. Corresponds to the JSON property updateTime

Returns:

  • (String)


3067
3068
3069
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3067

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 3074

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delegating_service_account = args[:delegating_service_account] if args.key?(:delegating_service_account)
  @display_name = args[:display_name] if args.key?(:display_name)
  @external_ips = args[:external_ips] if args.key?(:external_ips)
  @hubs = args[:hubs] if args.key?(:hubs)
  @logging = args[:logging] if args.key?(:logging)
  @name = args[:name] if args.key?(:name)
  @proxy_protocol_config = args[:proxy_protocol_config] if args.key?(:proxy_protocol_config)
  @service_discovery = args[:service_discovery] if args.key?(:service_discovery)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end