Class: Google::Apis::BeyondcorpV1alpha::ResourceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/beyondcorp_v1alpha/classes.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb,
lib/google/apis/beyondcorp_v1alpha/representations.rb

Overview

ResourceInfo represents the information/status of the associated resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceInfo

Returns a new instance of ResourceInfo.



4136
4137
4138
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 4136

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Required. Unique Id for the resource. Corresponds to the JSON property id

Returns:

  • (String)


4112
4113
4114
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 4112

def id
  @id
end

#resourceHash<String,Object>

Specific details for the resource. Corresponds to the JSON property resource

Returns:

  • (Hash<String,Object>)


4117
4118
4119
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 4117

def resource
  @resource
end

#statusString

Overall health status. Overall status is derived based on the status of each sub level resources. Corresponds to the JSON property status

Returns:

  • (String)


4123
4124
4125
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 4123

def status
  @status
end

#subArray<Google::Apis::BeyondcorpV1alpha::ResourceInfo>

List of Info for the sub level resources. Corresponds to the JSON property sub



4128
4129
4130
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 4128

def sub
  @sub
end

#timeString

The timestamp to collect the info. It is suggested to be set by the topmost level resource only. Corresponds to the JSON property time

Returns:

  • (String)


4134
4135
4136
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 4134

def time
  @time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4141
4142
4143
4144
4145
4146
4147
# File 'lib/google/apis/beyondcorp_v1alpha/classes.rb', line 4141

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @resource = args[:resource] if args.key?(:resource)
  @status = args[:status] if args.key?(:status)
  @sub = args[:sub] if args.key?(:sub)
  @time = args[:time] if args.key?(:time)
end